==> jc-1.4.0.tar.gz: soot/util/JimpleInputRep.h <==
// public class soot.util.JimpleInputRep

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 70e9a766fc6a846 soot_util_JimpleInputRep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_JimpleInputRep_H_
#define _JC_soot_util_JimpleInputRep_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_util_JimpleInputRep$object;

// Typedefs
typedef struct _jc_soot_util_JimpleInputRep$sub_refs	_jc_soot_util_JimpleInputRep$sub_refs;
typedef struct _jc_soot_util_JimpleInputRep$sub_nonrefs	_jc_soot_util_JimpleInputRep$sub_nonrefs;
typedef struct _jc_soot_util_JimpleInputRep$refs	_jc_soot_util_JimpleInputRep$refs;
typedef struct _jc_soot_util_JimpleInputRep$nonrefs	_jc_soot_util_JimpleInputRep$nonrefs;
typedef struct _jc_soot_util_JimpleInputRep$object	_jc_soot_util_JimpleInputRep$object;

typedef const struct _jc_soot_util_JimpleInputRep$vmethods	_jc_soot_util_JimpleInputRep$vmethods;
typedef const struct _jc_soot_util_JimpleInputRep$vtable	_jc_soot_util_JimpleInputRep$vtable;
typedef const struct _jc_soot_util_JimpleInputRep$vtype	_jc_soot_util_JimpleInputRep$vtype;

// Constructors
extern void _jc_soot_util_JimpleInputRep$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_util_JimpleInputRep$object *, struct _jc_soot_Singletons__24Global$object *);

// Virtual methods
extern struct _jc_java_io_InputStream$object *_jc_soot_util_JimpleInputRep$method$createInputStream$e51fe14db1e6f5a4(_jc_env *, struct _jc_soot_util_JimpleInputRep$object *, struct _jc_java_io_InputStream$object *);
extern struct _jc_java_lang_String$object *_jc_soot_util_JimpleInputRep$method$getFileExtension$9afd79be5de4c0cc(_jc_env *, struct _jc_soot_util_JimpleInputRep$object *);

// Virtual method descriptors
extern _jc_method _jc_soot_util_JimpleInputRep$method_info$createInputStream$e51fe14db1e6f5a4;
extern _jc_method _jc_soot_util_JimpleInputRep$method_info$getFileExtension$9afd79be5de4c0cc;

// Static methods
extern struct _jc_soot_util_JimpleInputRep$object *_jc_soot_util_JimpleInputRep$method$v$5bb238a48f3d12f8(_jc_env *);

// Virtual methods structure
struct _jc_soot_util_JimpleInputRep$vmethods {
	struct _jc_java_io_InputStream$object	*(*createInputStream$e51fe14db1e6f5a4)(_jc_env *, struct _jc_soot_util_JimpleInputRep$object *, struct _jc_java_io_InputStream$object *);
	struct _jc_java_lang_String$object	*(*getFileExtension$9afd79be5de4c0cc)(_jc_env *, struct _jc_soot_util_JimpleInputRep$object *);
};

// Vtable
struct _jc_soot_util_JimpleInputRep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_JimpleInputRep$vmethods	soot_util_JimpleInputRep;
};

// Vtype
struct _jc_soot_util_JimpleInputRep$vtype {
	_jc_type			type;
	_jc_soot_util_JimpleInputRep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_JimpleInputRep$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_JimpleInputRep$refs {
    _jc_soot_util_JimpleInputRep$sub_refs	soot_util_JimpleInputRep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_JimpleInputRep$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_JimpleInputRep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_JimpleInputRep$sub_nonrefs	soot_util_JimpleInputRep;
};

// Object instance structure
struct _jc_soot_util_JimpleInputRep$object {
	_jc_soot_util_JimpleInputRep$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_JimpleInputRep$vtype	*vtype;
	_jc_soot_util_JimpleInputRep$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_JimpleInputRep$vtype _jc_soot_util_JimpleInputRep$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_JimpleInputRep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_JimpleInputRep$class_object;

#endif	/* _JC_soot_util_JimpleInputRep_H_ */

==> jc-1.4.6.tar.gz: soot/util/JimpleInputRep.h <==
// public class soot.util.JimpleInputRep

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 70e9a766fc6a846 soot_util_JimpleInputRep

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_util_JimpleInputRep_H_
#define _JC_soot_util_JimpleInputRep_H_

// Forward structure declarations
struct _jc_java_io_InputStream$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_Singletons__24Global$object;
struct _jc_soot_util_JimpleInputRep$object;

// Typedefs
typedef struct _jc_soot_util_JimpleInputRep$sub_refs	_jc_soot_util_JimpleInputRep$sub_refs;
typedef struct _jc_soot_util_JimpleInputRep$sub_nonrefs	_jc_soot_util_JimpleInputRep$sub_nonrefs;
typedef struct _jc_soot_util_JimpleInputRep$refs	_jc_soot_util_JimpleInputRep$refs;
typedef struct _jc_soot_util_JimpleInputRep$nonrefs	_jc_soot_util_JimpleInputRep$nonrefs;
typedef struct _jc_soot_util_JimpleInputRep$object	_jc_soot_util_JimpleInputRep$object;

typedef const struct _jc_soot_util_JimpleInputRep$vmethods	_jc_soot_util_JimpleInputRep$vmethods;
typedef const struct _jc_soot_util_JimpleInputRep$vtable	_jc_soot_util_JimpleInputRep$vtable;
typedef const struct _jc_soot_util_JimpleInputRep$vtype	_jc_soot_util_JimpleInputRep$vtype;

// Constructors
extern void _jc_soot_util_JimpleInputRep$method$_init$bbe94f634b20986f(_jc_env *, struct _jc_soot_util_JimpleInputRep$object *, struct _jc_soot_Singletons__24Global$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_io_InputStream$object *_jc_soot_util_JimpleInputRep$method$createInputStream$e51fe14db1e6f5a4(_jc_env *, struct _jc_soot_util_JimpleInputRep$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_String$object *_jc_soot_util_JimpleInputRep$method$getFileExtension$9afd79be5de4c0cc(_jc_env *, struct _jc_soot_util_JimpleInputRep$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_util_JimpleInputRep$method_info$createInputStream$e51fe14db1e6f5a4;
extern _jc_method _jc_soot_util_JimpleInputRep$method_info$getFileExtension$9afd79be5de4c0cc;

// Static methods
extern struct _jc_soot_util_JimpleInputRep$object *_jc_soot_util_JimpleInputRep$method$v$5bb238a48f3d12f8(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_soot_util_JimpleInputRep$vmethods {
	struct _jc_java_io_InputStream$object	*(*createInputStream$e51fe14db1e6f5a4)(_jc_env *, struct _jc_soot_util_JimpleInputRep$object *, struct _jc_java_io_InputStream$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_String$object	*(*getFileExtension$9afd79be5de4c0cc)(_jc_env *, struct _jc_soot_util_JimpleInputRep$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_util_JimpleInputRep$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_util_JimpleInputRep$vmethods	soot_util_JimpleInputRep;
};

// Vtype
struct _jc_soot_util_JimpleInputRep$vtype {
	_jc_type			type;
	_jc_soot_util_JimpleInputRep$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_util_JimpleInputRep$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_util_JimpleInputRep$refs {
    _jc_soot_util_JimpleInputRep$sub_refs	soot_util_JimpleInputRep;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_util_JimpleInputRep$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_util_JimpleInputRep$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_util_JimpleInputRep$sub_nonrefs	soot_util_JimpleInputRep;
};

// Object instance structure
struct _jc_soot_util_JimpleInputRep$object {
	_jc_soot_util_JimpleInputRep$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_util_JimpleInputRep$vtype	*vtype;
	_jc_soot_util_JimpleInputRep$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_util_JimpleInputRep$vtype _jc_soot_util_JimpleInputRep$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_util_JimpleInputRep, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_util_JimpleInputRep$class_object;

#endif	/* _JC_soot_util_JimpleInputRep_H_ */
